'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _identity2 = require('ramda/src/identity');

var _identity3 = _interopRequireDefault(_identity2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _mcsLiteTheme = require('mcs-lite-theme');

var _styledComponents = require('styled-components');

require('recharts/lib/polyfill.js');

var _Tooltip = require('recharts/lib/component/Tooltip.js');

var _Tooltip2 = _interopRequireDefault(_Tooltip);

var _CartesianGrid = require('recharts/lib/cartesian/CartesianGrid.js');

var _CartesianGrid2 = _interopRequireDefault(_CartesianGrid);

var _YAxis = require('recharts/lib/cartesian/YAxis.js');

var _YAxis2 = _interopRequireDefault(_YAxis);

var _XAxis = require('recharts/lib/cartesian/XAxis.js');

var _XAxis2 = _interopRequireDefault(_XAxis);

var _Area = require('recharts/lib/cartesian/Area.js');

var _Area2 = _interopRequireDefault(_Area);

var _AreaChart = require('recharts/lib/chart/AreaChart.js');

var _AreaChart2 = _interopRequireDefault(_AreaChart);

var _ResponsiveContainer = require('recharts/lib/component/ResponsiveContainer.js');

var _ResponsiveContainer2 = _interopRequireDefault(_ResponsiveContainer);

var _RechartTooltip = require('./RechartTooltip');

var _RechartTooltip2 = _interopRequireDefault(_RechartTooltip);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var lighten = (0, _mcsLiteTheme.opacity)(0.4);

var DataPointAreaChart = function DataPointAreaChart(_ref) {
  var data = _ref.data,
      theme = _ref.theme,
      kind = _ref.kind,
      type = _ref.type,
      isAnimationActive = _ref.isAnimationActive,
      XAxisProps = _ref.XAxisProps,
      tooltipProps = _ref.tooltipProps;
  return _react2.default.createElement(
    _ResponsiveContainer2.default,
    null,
    _react2.default.createElement(
      _AreaChart2.default,
      { data: data, margin: { left: -20 } },
      _react2.default.createElement(
        'defs',
        null,
        _react2.default.createElement(
          'linearGradient',
          { id: 'areaGradient', x1: '0.5', y1: '0', x2: '0.5', y2: '1' },
          _react2.default.createElement('stop', { offset: '0', stopColor: theme.color[kind], stopOpacity: '0.5' }),
          _react2.default.createElement('stop', {
            offset: '1',
            stopColor: lighten(theme.color[kind]),
            stopOpacity: '0.5'
          })
        )
      ),
      _react2.default.createElement(_XAxis2.default, Object.assign({
        dataKey: 'updatedAt',
        tick: { fill: theme.color.grayDark },
        height: 24,
        tickLine: false,
        tickSize: 12,
        axisLine: { stroke: theme.color.grayDark },
        interval: 'preserveStartEnd'
      }, XAxisProps)),
      _react2.default.createElement(_YAxis2.default, {
        tickLine: false,
        tick: { fill: theme.color.grayDark },
        axisLine: { stroke: theme.color.grayDark }
      }),
      _react2.default.createElement(_CartesianGrid2.default, { strokeDasharray: '3 3', vertical: false }),
      _react2.default.createElement(_Tooltip2.default, Object.assign({
        content: _react2.default.createElement(_RechartTooltip2.default, null),
        cursor: { stroke: theme.color.warning, strokeDasharray: '4, 2' }
      }, tooltipProps)),
      _react2.default.createElement(_Area2.default, {
        type: type,
        dataKey: 'value',
        isAnimationActive: isAnimationActive,
        stroke: theme.color[kind],
        fill: 'url(#areaGradient)'
      })
    )
  );
};

DataPointAreaChart.displayName = 'DataPointAreaChart';
DataPointAreaChart.propTypes = {
  data: _propTypes2.default.arrayOf(_propTypes2.default.shape({
    updatedAt: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]).isRequired,
    value: _propTypes2.default.number.isRequired
  })).isRequired,
  theme: _propTypes2.default.object.isRequired,
  kind: _propTypes2.default.string,
  type: _propTypes2.default.string,
  isAnimationActive: _propTypes2.default.bool,
  XAxisProps: _propTypes2.default.shape({
    tickFormatter: _propTypes2.default.func
  }),
  tooltipProps: _propTypes2.default.shape({
    formatter: _propTypes2.default.func,
    labelFormatter: _propTypes2.default.func
  })
};
DataPointAreaChart.defaultProps = {
  kind: 'primary',
  type: 'linear',
  isAnimationActive: false,
  XAxisProps: {
    tickFormatter: _identity3.default
  },
  tooltipProps: {
    formatter: function formatter(value) {
      return 'Datapoint: ' + value;
    },
    labelFormatter: function labelFormatter(value) {
      return 'Time: ' + value;
    }
  }
};

exports.default = (0, _styledComponents.withTheme)(DataPointAreaChart);
module.exports = exports['default'];